@@ -7,7 +7,8 @@
 #include <objc/Object.h>
 #include <gtk/gtk.h>
 
-#include <obgtk/obgtkAcceleratorTable.h>
+#include <obgtk/obgtkAccelGroup.h>
+#include <obgtk/obgtkAccelLabel.h>
 #include <obgtk/obgtkAdjustment.h>
 #include <obgtk/obgtkAlignment.h>
 #include <obgtk/obgtkApp.h>
@@ -20,6 +21,7 @@
 #include <obgtk/obgtkCheckButton.h>
 #include <obgtk/obgtkCheckMenuItem.h>
 #include <obgtk/obgtkCList.h>
+#include <obgtk/obgtkCTree.h>
 #include <obgtk/obgtkColorSelection.h>
 #include <obgtk/obgtkColorSelectionDialog.h>
 #include <obgtk/obgtkCombo.h>
@@ -33,6 +35,7 @@
 #include <obgtk/obgtkEventBox.h>
 #include <obgtk/obgtkFileSelection.h>
 #include <obgtk/obgtkFixed.h>
+#include <obgtk/obgtkFontSelection.h>
 #include <obgtk/obgtkFrame.h>
 #include <obgtk/obgtkGammaCurve.h>
 #include <obgtk/obgtkHandleBox.h>
@@ -57,9 +60,11 @@
 #include <obgtk/obgtkNotebook.h>
 #include <obgtk/obgtkObject.h>
 #include <obgtk/obgtkOptionMenu.h>
+#include <obgtk/obgtkPacker.h>
 #include <obgtk/obgtkPaned.h>
 #include <obgtk/obgtkPixmap.h>
 #include <obgtk/obgtkPreview.h>
+#include <obgtk/obgtkProgress.h>
 #include <obgtk/obgtkProgressBar.h>
 #include <obgtk/obgtkRadioButton.h>
 #include <obgtk/obgtkRadioMenuItem.h>
@@ -72,6 +77,7 @@
 #include <obgtk/obgtkSpinButton.h>
 #include <obgtk/obgtkTable.h>
 #include <obgtk/obgtkText.h>
+#include <obgtk/obgtkTipsQuery.h>
 #include <obgtk/obgtkToggleButton.h>
 #include <obgtk/obgtkToolbar.h>
 #include <obgtk/obgtkTooltips.h>
