@@ -34,6 +34,25 @@
   return gtk_editable_get_chars(gtkeditable, start_pos, end_pos);
 }
 
+#if (GTK_MAJOR_VERSION==1) && (GTK_MINOR_VERSION==1)
+- cut_clipboard
+{
+  gtk_editable_cut_clipboard(gtkeditable);
+  return self;
+}
+
+- copy_clipboard
+{
+  gtk_editable_copy_clipboard(gtkeditable);
+  return self;
+}
+
+- paste_clipboard
+{
+  gtk_editable_paste_clipboard(gtkeditable);
+  return self;
+}
+#else
 - cut_clipboard:(guint32) time
 {
   gtk_editable_cut_clipboard(gtkeditable, time);
@@ -51,6 +70,7 @@
   gtk_editable_paste_clipboard(gtkeditable, time);
   return self;
 }
+#endif
 
 - claim_selection:(gboolean) claim :(guint32) time
 {
