@@ -1,4 +1,4 @@
-#include "obgtk.h"
+#include "obgtkHBox.h"
 
 @implementation Gtk_HBox
 - castGtkHBox:(GtkHBox *)castitem
