@@ -1,4 +1,4 @@
-#include "obgtk.h"
+#include "obgtkHScale.h"
 
 @implementation Gtk_HScale
 - init
