@@ -1,4 +1,4 @@
-#include "obgtk.h"
+#include "obgtkImage.h"
 
 @implementation Gtk_Image
 - init
