@@ -3,7 +3,11 @@
 
 #include <obgtk/obgtkMenuShell.h>
 #include <obgtk/obgtkWidget.h>
+#ifdef GTK_HAVE_FEATURES_1_1_0
+#include <obgtk/obgtkAccelGroup.h>
+#else
 #include <obgtk/obgtkAcceleratorTable.h>
+#endif
 #include <obgtk/obgtkMenuItem.h>
 #include <gtk/gtkmenu.h>
 
@@ -23,7 +27,11 @@
 - popdown;
 - (id) get_active;
 - set_active:(gint) index;
+#ifdef GTK_HAVE_FEATURES_1_1_0
+- set_accel_group:(id) group;
+#else
 - set_accelerator_table:(id) table;
+#endif
 - attach_to_widget:(id) attach_widget
     detachFunction:(GtkMenuDetachFunc) detacher;
 - (id) get_attach_widget;
