@@ -11,7 +11,7 @@
   GtkRange *gtkrange;
 }
 - castGtkRange:(GtkRange *) castitem;
-- (Gtk_Adjustment *)get_adjustment;
+- (id)get_adjustment;
 - set_update_policy:(GtkUpdateType) policy;
 - set_adjustment:(Gtk_Adjustment *) adjustment;
 - draw_background;
@@ -23,7 +23,18 @@
 - trough_click:(gint) x
 	      :(gint) y
 	      :(gfloat *) jump_perc;
-- (gfloat) calc_value:(gint) position;
+- default_hslider_update;
+- default_vslider_update;
+- default_htrough_click:(gint) x
+		       :(gint) y
+		       :(gfloat *) jump_perc;
+- default_vtrough_click:(gint) x
+		       :(gint) y
+		       :(gfloat *) jump_perc;
+- default_hmotion:(gint) xdelta
+		 :(gint) ydelta;
+- default_vmotion:(gint) xdelta
+		 :(gint) ydelta;
 @end
 
 #endif /* OBGTK_RANGE_H */
