@@ -7,21 +7,22 @@
   return [super castGtkEntry:GTK_ENTRY(castitem)];
 }
 
-- initWithSpinInfo:(Gtk_Adjustment *) adjustment
+- initWithSpinInfo:(id) adjustment
 		  :(gfloat) climb_rate
 		  :(gint) digits
 {
-  return [self castGtkSpinButton:GTK_SPIN_BUTTON(gtk_spin_button_new(adjustment->gtkadjustment, climb_rate, digits))];
+  return [self castGtkSpinButton:GTK_SPIN_BUTTON(gtk_spin_button_new(GTK_ADJUSTMENT([adjustment getGtkObject]), climb_rate, digits))];
 }
 
-- set_adjustment:(Gtk_Adjustment *) adjustment
+- set_adjustment:(id) adjustment
 {
-  gtk_spin_button_set_adjustment(gtkspinbutton, adjustment->gtkadjustment);
+  gtk_spin_button_set_adjustment(gtkspinbutton,
+				 GTK_ADJUSTMENT([adjustment getGtkObject]));
 }
 
 - (id) get_adjustment
 {
-  return (id)gtk_object_get_data(GTK_OBJECT(gtk_spin_button_get_adjustment(gtkspinbutton)), "objc_id");
+  return (id)gtk_object_get_data_by_id(GTK_OBJECT(gtk_spin_button_get_adjustment(gtkspinbutton)), OBJC_ID());
 }
 
 - set_digits:(gint) digits
@@ -51,4 +52,22 @@
   gtk_spin_button_set_update_policy(gtkspinbutton, policy);
   return self;
 }
+
+- set_numeric:(gint) numeric
+{
+  gtk_spin_button_set_numeric(gtkspinbutton, numeric);
+  return self;
+}
+
+- spin:(guint) direction :(gfloat) step
+{
+  gtk_spin_button_spin(gtkspinbutton, direction, step);
+  return self;
+}
+
+- set_wrap:(gint) wrap
+{
+  gtk_spin_button_set_wrap(gtkspinbutton, wrap);
+  return self;
+}
 @end
