@@ -1,4 +1,4 @@
-#include "obgtk.h"
+#include "obgtkViewport.h"
 
 @implementation Gtk_Viewport
 - init
